@@ -112,12 +112,12 @@ class Sheets:
             antigo = se.pk
             add, worksheet = addicionar(se)
             x = 1
-            y = None
             worksheet = self.sh.worksheet(worksheet)
             pks = worksheet.col_values(1)
             for i in pks:
                 if int(i) == int(antigo):
-                    worksheet.delete_row(y)
+                    worksheet.delete_row(x)
+                x = x+1
             return True
         else:
             return False
